@@ -2,6 +2,7 @@ from __future__ import absolute_import
 
 from collections import defaultdict
 from contextlib import contextmanager
+import logging
 
 import click
 import flask
@@ -12,9 +13,22 @@ from keg import current_app
 from keg.extensions import gettext as _
 
 
+try:
+    import dotenv
+except ImportError:
+    dotenv = None
+
+try:
+    from flask.helpers import get_load_dotenv
+except ImportError:
+    def get_load_dotenv(default=False):
+        return False
+
+
 class KegAppGroup(flask.cli.AppGroup):
-    def __init__(self, create_app, add_default_commands=True, *args, **kwargs):
+    def __init__(self, create_app, add_default_commands=True, load_dotenv=True, *args, **kwargs):
         self.create_app = create_app
+        self.load_dotenv = load_dotenv
 
         flask.cli.AppGroup.__init__(self, *args, **kwargs)
         if add_default_commands:
@@ -51,6 +65,9 @@ class KegAppGroup(flask.cli.AppGroup):
         return click.Group.get_command(self, ctx, name)
 
     def main(self, *args, **kwargs):
+        if get_load_dotenv(self.load_dotenv):
+            flask.cli.load_dotenv()
+
         obj = kwargs.get('obj')
         if obj is None:
             obj = flask.cli.ScriptInfo(create_app=self.create_app)
@@ -242,8 +259,9 @@ class CLILoader(object):
             into a dict which will be given as kwargs to the app's .init() method.
         """
         retval = dict(config_profile=cli_options.get('profile', None), config={})
-        if cli_options.get('quiet', False):
-            retval['config']['KEG_LOG_STREAM_ENABLED'] = False
+        quiet = cli_options.get('quiet', 0)
+        verbose = cli_options.get('verbose', 0)
+        retval['config']['KEG_LOG_LEVEL'] = logging.WARNING + 10 * quiet - 10 * verbose
         return retval
 
     def create_script_options(self):
@@ -251,9 +269,12 @@ class CLILoader(object):
         return [
             click.Option(['--profile'], is_eager=True, default=None, callback=self.options_callback,
                          help=_('Name of the configuration profile to use.'),),
-            click.Option(['--quiet'], is_eager=True, is_flag=True, default=False,
-                         callback=self.options_callback,
-                         help=_('Set default logging level to logging.WARNING.')),
+            click.Option(['--quiet', '-q'], is_eager=True, default=0,
+                         count=True, callback=self.options_callback,
+                         help=_('Increase logging level for reduced logging')),
+            click.Option(['--verbose', '-v'], is_eager=True, default=0,
+                         count=True, callback=self.options_callback,
+                         help=_('Decrease logging level for increased logging')),
             click.Option(['--help-all'], is_eager=True, is_flag=True, expose_value=False,
                          callback=self.help_all_callback,
                          help=_('Show all commands with subcommands.')),
